==========================
Trust No One Cloud Storage
==========================

The tnocs library and command line interface (CLI) program provides
access to "the cloud" without sacrificing any data confidentiality or
integrity.
